diff --git a/scp/logout.php b/scp/logout.php
index 4cf519d35bc3a66597853f3a96f661190a245b33..806e0afb13fdb6df2aeabb7cec2bb083f4c69776 100644
--- a/scp/logout.php
+++ b/scp/logout.php
@@ -1,29 +1,33 @@
-<?php
-/*********************************************************************
-    logout.php
-
-    Log out staff
-    Destroy the session and redirect to login.php
-
-    Peter Rotich <peter@osticket.com>
-    Copyright (c)  2006-2013 osTicket
-    http://www.osticket.com
-
-    Released under the GNU General Public License WITHOUT ANY WARRANTY.
-    See LICENSE.TXT for details.
-
-    vim: expandtab sw=4 ts=4 sts=4:
-**********************************************************************/
-require('staff.inc.php');
-
-//Check token: Make sure the user actually clicked on the link to logout.
-if(!$_GET['auth'] || !$ost->validateLinkToken($_GET['auth']))
-    @header('Location: index.php');
-
-$thisstaff->logOut();
-//Clear upgrader session on logout.
-$_SESSION['ost_upgrader'] = null;
-
-@header('Location: login.php');
-require('login.php');
-?>
+<?php
+/*********************************************************************
+    logout.php
+
+    Log out staff
+    Destroy the session and redirect to login.php
+
+    Peter Rotich <peter@osticket.com>
+    Copyright (c)  2006-2013 osTicket
+    http://www.osticket.com
+
+    Released under the GNU General Public License WITHOUT ANY WARRANTY.
+    See LICENSE.TXT for details.
+
+    vim: expandtab sw=4 ts=4 sts=4:
+**********************************************************************/
+require('staff.inc.php');
+
+//Check token: Make sure the user actually clicked on the link to logout.
+if(!$_GET['auth'] || !$ost->validateLinkToken($_GET['auth']))
+    @header('Location: index.php');
+
+$thisstaff->logOut();
+
+//Clear any ticket locks the staff has.
+TicketLock::removeStaffLocks($thisstaff->getId());
+
+//Clear upgrader session on logout.
+$_SESSION['ost_upgrader'] = null;
+
+@header('Location: login.php');
+require('login.php');
+?>